/**
 * Created by haochai on 16/8/18.
 */
define(["vue", "common/config", "common/promise", "router"], function (Vue, config, promise$1, Router) {
  Vue.use(Router);
  var router = new Router();
  var Promise = Promise || promise$1;

  function post(uri, params, opts) {
    config.isAllowSubmit = false;
    if (!opts || opts.loading) {
      config.loading(true, uri);
    }
    if (!params.user_id) {
      params.user_id = config.session.user_id;
    }
    if (config.session.mark) {
      params.g_feed_id = config.session.g_feed_id;
    }


    console.log('POST_url:' + uri);
    console.log('POST_params:' + JSON.stringify(params));
    return Vue.http.post(uri, params).then(function (res) {
      if (!opts) {
        config.loading(false, uri + "  1"); // 隐藏加载框
      } else {
        opts.control = opts.control ? opts.control : false;
        if (!opts.control && opts.loading) {
          config.loading(false, uri + "  1"); // 隐藏加载框
        }
      }
      var result = res.json();
      if (result.meta.code == 0) {

        console.log("POST_SUCCESS" + JSON.stringify(result));

        config.isAllowSubmit = true;
        return Promise.resolve(result.data);
      } else {
        console.log("POST_Failed" + JSON.stringify(result));

        if (params.code && result.meta.code == 1 && !result.data.length) {
          window.location.reload();
          return;
        }

        config.isAllowSubmit = true;
        return Promise.reject(result.meta);
      }
    }, function (err) {
      console.log("POST_ERROR" + JSON.stringify(err));

      config.loading(false);
      // 网络错误导出到error
      if (!err.body && !err.status) {
        router.replace({name: "error"});
      }

      config.isAllowSubmit = true;
      if (!opts.control) {
        if (!opts || opts.loading) {
          config.loading(false, uri + "  2"); // 隐藏加载框
        }
      }
      err.msg = err.message;
      return Promise.reject(err);
    }).catch(function (err) {
      console.error('POST_catch' + JSON.stringify(err));
      config.isAllowSubmit = true;
      err.msg = err.message;
      return Promise.reject(err);
    });
  }

  function get(uri, params, opts) {
    config.isAllowSubmit = false;
    if (!opts || opts.loading) {
      config.loading(true, uri);
    }

    if (!params.user_id) {
      params.user_id = config.session.user_id;
    }
    if (config.session.mark) {
      params.g_feed_id = config.session.g_feed_id;
    }

    return Vue.http.get(uri, {params: params}).then(function (res) {
      if (!opts) {
        config.loading(false, uri + "  1"); // 隐藏加载框
      } else {
        opts.control = opts.control ? opts.control : false;
        if (!opts.control && opts.loading) {
          config.loading(false, uri + "  1"); // 隐藏加载框
        }
      }
      var result = res.json();
      if (result.meta.code == 0) {
        config.isAllowSubmit = true;
        return Promise.resolve(result.data);
      } else {
        config.isAllowSubmit = true;
        return Promise.reject(result.meta);
      }
    }, function (err) {
      config.isAllowSubmit = true;
      console.error("POST ERROR-2", uri, err.message);

      // 网络错误导出到error
      if (!err.body && !err.status && !err.statusText) {
        router.replace({name: "error"});
      }

      config.loading(false);
      if (!opts.control) {
        if (!opts || opts.loading) {
          config.loading(false, uri + "  2"); // 隐藏加载框
        }
      }
      err.msg = err.message;
      return Promise.reject(err);
    }).catch(function (err) {
      config.isAllowSubmit = true;
      err.msg = err.message;
      console.error(err);
      return Promise.reject(err);
    });
  }

  // 登录
  function login() {
    var uri = config.url + "/user/checkLogin";
    var params = {code: config.code};

    if (config.entry == 2) {
      //群组名片入口
      params.entryType = 2;
    } else if ((config.entry == 3 || config.entry == 4) && config.feedType == "g") {
      //群通知入口
      params.entryType = 2;
    } else {
      //非群组入口
      params.entryType = 1;
    }
    var opt = {loading: false};
    return post(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }


  //详情页
  function activeInfo(param, opt) {
    var uri = config.url + "/activity/detailactivity";
    opt = opt ? opt : {loading: true};
    return post(uri, param, opt).then(function (data) {
      config.loginData = data;
      return Promise.resolve(data);
    });
  }

  //获取首页列表
  function getIndexList(params, opt) {
    var uri;
    if (config.session.mark) {
      uri = config.url + "/activity/getGroupList";
    } else {
      uri = config.url + "/activity/getlist";
    }
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //获取我的活动列表
  function getMyList(params, opt) {
    var uri;
    if (opt.showMyTap === 1) {
      uri = config.url + "/activity/getmyapplylist";
    } else if (opt.showMyTap === 2) {
      uri = config.url + "/activity/getmypublist";
    }

    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //获取banner
  function getBannerDate(params, opt) {
    var uri = config.toon_url + "/banner/list";
    return post(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //签到接口
  function getSign(param) {
    var uri = config.url + "/checkin/save";
    return post(uri, param).then(function (data) {
      config.loginData = data;
      return Promise.resolve(data);
    });
  }

  //发布活动
  function addActive(param) {
    var uri = config.url + "/activity/addactivity";
    return post(uri, param).then(function (data) {
      config.loginData = data;
      return Promise.resolve(data);
    });
  }

  //取消报名
  function cancelApply(param) {
    var uri = config.url + "/apply/revoke";
    return post(uri, param).then(function (data) {
      config.loginData = data;
      return Promise.resolve(data);
    });
  }

  //搜索
  function search(params, opt) {
    var uri;
    uri = opt.type == "dynamic-state" ? config.url + "/dynamic/getsearchlist" : config.url + "/activity/searchlist";
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //我要报名
  function submitApply(param) {
    var uri = config.url + "/apply/save";
    return post(uri, param).then(function (data) {
      config.loginData = data;
      return Promise.resolve(data);
    });
  }

  //查询报名人数
  function getApplyStatistics(param, opt) {
    var uri = config.url + "/apply/getStat";
    return get(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //查询审核列表
  function getApprovalList(param, opt) {
    var uri = config.url + "/apply/showList";
    return get(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //导出名单
  function exportList(param, opt) {
    var uri = config.url + "/activity/exportapplyinfo";
    return post(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //审核报名
  function doApply(param, opt) {
    var uri = config.url + "/apply/verify";
    return post(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //签到列表
  function getCheckInList(param, opt) {
    var uri = config.url + "/checkin/showList";
    return get(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //签到列表统计
  function getCheckInStatistics(param, opt) {
    var uri = config.url + "/checkin/getStat";
    return get(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //切换名片
  function userSys(param, opt) {
    var uri = config.url + "/toon/getlistfeedinfo";
    return post(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //无身份首页
  function getNoIDIndexList(param, opt) {
    var uri = config.url + "/share/noidentity";
    return get(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //无身份详情nonidentitydetail
  function noIDActiveInfo(param, opt) {
    var uri = config.url + "/share/nonidentitydetail";
    return post(uri, param).then(function (data) {
      config.loginData = data;
      return Promise.resolve(data);
    });
  }

  //无身份登录
  function noIDLogin(param, opt) {
    var uri = config.url + "/share/nochecklogin";
    if (config.entry) {
      param.entryType = config.entry;
    }
    return post(uri, param, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //获取动态--活动（近期、往期活动）列表
  function getDynamicList(params, opt) {
    var uri = config.url + "/dynamic/getDataRows";
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //获取活动首页各模块列表
  function getIndexModuleList(params, opt) {
    var uri = config.url + "/activity/getPanelList";
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function getModuleList(params, opt) {
    var portArr = ["/activity/getrecommendlist", "/activity/gethotlist", "/activity/getrecentlist"];
    var uri = config.url + portArr[opt.type];
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function getNoticeList(params, opt) {
    var uri = config.url + "/activity/noticelist";
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function addNotice(params, opt) {
    var uri = config.url + "/activity/addnotice";
    return post(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function groupChat(params, opt) {
    var uri = config.url + "/activity/groupchat";
    return post(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function shareGetOpenList(params, opt) {
    var uri = config.url + "/share/getOpenList";
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function getSignContent(params, opt) {
    var uri = config.url + "/activity/getacinfobyuser";
    return post(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function creatComment(params, opt) {
    var uri = config.url + "/comment/add";
    return post(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function getCommentList(params, opt) {
    var uri = config.url + "/comment/getCommentList";
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function getMakeCode(params, opt) {
    var uri = config.url + "/v1/api/generateVoteCode";
    return post(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function attentionUser(params, opt) {
    var uri = config.url + "/activity/attentionUser";
    return post(uri, params, {loading: false}).then(function (data) {
      return Promise.resolve(data);
    });
  }

  //function heartBeat(params,opt){
  //   var uri = config.url + "/activity/heartBeat";
  //   return post(uri,params,{loading:false}).then(function (data) {
  //       return Promise.resolve(data);
  //   });
  //}
  //function getHeartList(params,opt){
  //   var uri = config.url + "/activity/heartBeatList";
  //   return get(uri,params,opt).then(function (data) {
  //       return Promise.resolve(data);
  //   });
  //}
  //function generateShaiCode(params,opt){
  //   var uri = config.url + "/v1/api/generateShaiCode";
  //   return post(uri,params,opt).then(function (data) {
  //       return Promise.resolve(data);
  //   });
  //}
  //function shaiApiByActivity(params,opt){
  //   var uri = config.url + "/v1/api/shaiApiByActivity";
  //   return post(uri,params,opt).then(function (data) {
  //       return Promise.resolve(data);
  //   });
  //}
  //function getShaiList(params,opt){
  //   var uri = config.url + "/v1/api/getShaiList";
  //   return post(uri,params,opt).then(function (data) {
  //       return Promise.resolve(data);
  //   });
  //}
  function getApplyUserInfo(params, opt) {
    var uri = config.url + "/activity/getApplyUserInfo";
    return post(uri, params, {loading: false}).then(function (data) {
      return Promise.resolve(data);
    });
  }

  function getCityList(params, opt) {
    var uri = config.url + "/activity/getcitylist";
    return get(uri, params, opt).then(function (data) {
      return Promise.resolve(data);
    });
  }

  return {
    login: login,
    activeInfo: activeInfo,
    getIndexList: getIndexList,
    getMyList: getMyList,
    getSign: getSign,
    addActive: addActive,
    search: search,
    cancelApply: cancelApply,
    submitApply: submitApply,
    getApplyStatistics: getApplyStatistics,
    getApprovalList: getApprovalList,
    exportList: exportList,
    doApply: doApply,
    getCheckInList: getCheckInList,
    getCheckInStatistics: getCheckInStatistics,
    userSys: userSys,
    getNoIDIndexList: getNoIDIndexList,
    noIDActiveInfo: noIDActiveInfo,
    noIDLogin: noIDLogin,
    getDynamicList: getDynamicList,
    getIndexModuleList: getIndexModuleList,
    getModuleList: getModuleList,
    getNoticeList: getNoticeList,
    addNotice: addNotice,
    groupChat: groupChat,
    shareGetOpenList: shareGetOpenList,
    getSignContent: getSignContent,
    creatComment: creatComment,
    getCommentList: getCommentList,
    getMakeCode: getMakeCode,
    attentionUser: attentionUser,
    getBannerDate: getBannerDate,
    getApplyUserInfo: getApplyUserInfo,
    //heartBeat:heartBeat,
    //getHeartList:getHeartList,
    //generateShaiCode:generateShaiCode,
    //shaiApiByActivity:shaiApiByActivity,
    //getShaiList:getShaiList,
    getCityList: getCityList
  };
});
