/**
 *router.js
 * 路由文件
 *     --Created by Li Yubo on 2016/10/24 17:18.
 */
define(["vue", "router", "resource", "common/config", "common/app", "common/api", "common/v-dialog", "analytics", "base64"], function (Vue, Router, VueResource, config, app, api, dialog, analytics, base64) {
  Vue.use(Router);
  Vue.use(VueResource);
  var getComponent = function (name, loading, noAutoClose) {
    var fn;
    if (loading === 0) {
      fn = function (resolve) {
        require([name], function (module) {
          resolve(module);
        }, function (err) {
          alert("请求失败");
        });
      }
    } else {
      fn = function (resolve) {
        //首次加载模块打开Loading遮罩
        // config.loading(true);
        require([name], function (module) {
          resolve(module);
          //加载完毕，关闭遮罩
          if (!noAutoClose) config.loading(false);
        }, function (err) {
          //加载失败，关闭遮罩
          // config.loading(false);
          alert("请求失败");
        });
      }
    }
    return fn;
  };
  var router = new Router();

  //详情路由封装
  var detailRouter = {
    //活动详情页
    "/active-info": {
      name: "active-info",
      component: getComponent("module/active-info", 1, true),
      subRoutes: {
        //发布评论
        "/bbs-create": {
          name: "bbs-create",
          component: getComponent("module/bbs-create")
        },
        //活动二维码
        "/qr-code": {
          name: "qr-code",
          component: getComponent("module/qr-code")
        },
        //活动签到二维码
        "/activity-code": {
          name: "activity-code",
          component: getComponent("module/activity-code")
        },
        //查看报名列表
        "/register-list-page": {
          name: "register-list-page",
          component: getComponent("module/register-list-page")
        },
        //查看签到列表
        "/sign-list": {
          name: "sign-list",
          component: getComponent("module/sign-list")
        },
        //发布公告
        "/add-notice": {
          name: "add-notice",
          component: getComponent("module/add-notice")
        },
        //公告列表
        "/notice-list": {
          name: "notice-list",
          component: getComponent("module/notice-list"),
          subRoutes: {
            //发布公告
            "/add-notice": {
              name: "addNotice",
              component: getComponent("module/add-notice")
            }
          }
        },
        //Ta们很心动页
        //"/heartbeat":{
        //    name: "heartbeat",
        //    component: getComponent("module/heartbeat")
        //},
        //查看活动描述
        "/active-intro": {
          name: "active-intro",
          component: getComponent("module/active-intro")
        },
        //审核列表
        "/approval-list": {
          name: "approval-list",
          component: getComponent("module/approval-list")
        }

      }
    },
    "/no-active-info": {
      name: "no-active-info",
      component: getComponent("module/no-active-info", 1, true),
      subRoutes: {
        //发布评论
        "/bbs-create": {
          name: "bbs-create",
          component: getComponent("module/bbs-create")
        },
        //活动二维码
        "/qr-code": {
          name: "qr-code",
          component: getComponent("module/qr-code")
        },
        //活动签到二维码
        "/activity-code": {
          name: "activity-code",
          component: getComponent("module/activity-code")
        },
        //查看报名列表
        "/register-list-page": {
          name: "register-list-page",
          component: getComponent("module/register-list-page")
        },
        //查看签到列表
        "/sign-list": {
          name: "sign-list",
          component: getComponent("module/sign-list")
        },
        //发布公告
        "/add-notice": {
          name: "add-notice",
          component: getComponent("module/add-notice")
        },
        //公告列表
        "/notice-list": {
          name: "notice-list",
          component: getComponent("module/notice-list"),
          subRoutes: {
            //发布公告
            "/add-notice": {
              name: "addNotice",
              component: getComponent("module/add-notice")
            }
          }
        },
        //Ta们很心动页
        //"/heartbeat":{
        //    name: "heartbeat",
        //    component: getComponent("module/heartbeat")
        //},
        //查看活动描述
        "/active-intro": {
          name: "active-intro",
          component: getComponent("module/active-intro")
        }
      }
    },
    //编辑页
    "/edit-active": {
      name: "edit-active",
      component: getComponent("module/edit-active"),
      subRoutes: {
        //活动描述
        "/describe": {
          name: "edit-describe",
          component: getComponent("module/describe")
        },
        //自定义页
        "/add-apply-info": {
          name: "edit-apply-info",
          component: getComponent("module/edit-apply-info")
        }
      }
    },
    //报名页
    "/apply": {
      name: "apply",
      component: getComponent("module/apply")
    },
    //审核列表
    "/approval-list": {
      name: "approval-list",
      component: getComponent("module/approval-list")
    },
    //发布页
    "/add-active": {
      name: "add-active",
      component: getComponent("module/add-active"),
      subRoutes: {
        //活动描述
        "/describe": {
          name: "describe",
          component: getComponent("module/describe")
        },
        //自定义页
        "/add-apply-info": {
          name: "add-apply-info",
          component: getComponent("module/add-apply-info")
        }
      }
    },
    //错误页
    "/error": {
      name: "error",
      component: getComponent("module/error")
    },
    //错误页
    "/del": {
      name: "del",
      component: getComponent("module/del")
    },
    "/city-list": {
      name: "city-list",
      component: getComponent("module/city-list")
    }
  };

  if (config.entry == 4) {
    router.map({
      "/root": {
        name: "root",
        component: {
          template: ""
        }
      },
      //审核列表
      "/approval-list": {
        name: "approval-list",
        component: getComponent("module/approval-list")
      },
      //错误页
      "/error": {
        name: "error",
        component: getComponent("module/error")
      },
      //错误页
      "/del": {
        name: "del",
        component: getComponent("module/del")
      }
    });
  } else if (config.entry == 101) {
    //TODO 无身份详情路由
    router.map({
      "/root": {
        name: "root",
        component: {
          template: ""
        }
      },
      "/no-active-info": {
        name: "no-active-info",
        component: getComponent("module/no-active-info", 1, true),
        subRoutes: {
          //发布评论
          "/bbs-create": {
            name: "bbs-create",
            component: getComponent("module/bbs-create")
          },
          //活动二维码
          "/qr-code": {
            name: "qr-code",
            component: getComponent("module/qr-code")
          },
          //活动签到二维码
          "/activity-code": {
            name: "activity-code",
            component: getComponent("module/activity-code")
          },
          //报名页
          "/apply": {
            name: "apply",
            component: getComponent("module/apply")
          },
          //查看报名列表
          "/register-list-page": {
            name: "register-list-page",
            component: getComponent("module/register-list-page")
          },
          //查看签到列表
          "/sign-list": {
            name: "sign-list",
            component: getComponent("module/sign-list")
          },
          //发布公告
          "/add-notice": {
            name: "add-notice",
            component: getComponent("module/add-notice")
          },
          //公告列表
          "/notice-list": {
            name: "notice-list",
            component: getComponent("module/notice-list"),
            subRoutes: {
              //发布公告
              "/add-notice": {
                name: "addNotice",
                component: getComponent("module/add-notice")
              }
            }
          },
          //查看活动描述
          "/active-intro": {
            name: "active-intro",
            component: getComponent("module/active-intro")
          }
        }
      },
      //编辑页
      "/edit-active": {
        name: "edit-active",
        component: getComponent("module/edit-active"),
        subRoutes: {
          //活动描述
          "/describe": {
            name: "edit-describe",
            component: getComponent("module/describe")
          },
          //自定义页
          "/add-apply-info": {
            name: "edit-apply-info",
            component: getComponent("module/edit-apply-info")
          }

        }
      },
      //审核列表
      "/approval-list": {
        name: "approval-list",
        component: getComponent("module/approval-list")
      },
      //错误页
      "/error": {
        name: "error",
        component: getComponent("module/error")
      },
      //错误页
      "/del": {
        name: "del",
        component: getComponent("module/del")
      },
      "/city-list": {
        name: "city-list",
        component: getComponent("module/city-list")
      }
    });
  } else if (config.entry == 103) {//个人名片--我的
    router.map({
      "/root": {
        name: "root",
        component: {
          template: ""
        }
      },
      //动态--活动
      "/my-list": {
        name: "my-list",
        component: getComponent("module/my-list"),
        subRoutes: detailRouter
      },
      //错误页
      "/error": {
        name: "error",
        component: getComponent("module/error")
      },
      //错误页
      "/del": {
        name: "del",
        component: getComponent("module/del")
      },
      //分享页
      "/share-active-info": {
        name: "share-active-info",
        component: getComponent("module/share-active-info")
      }
    });
  } else if (config.entry == 105) {//发布页入口
    router.map({
      "/root": {
        name: "root",
        component: {
          template: ""
        }
      },
      //发布页
      "/add-active": {
        name: "add-active",
        component: getComponent("module/add-active"),
        subRoutes: {
          //活动描述
          "/describe": {
            name: "describe",
            component: getComponent("module/describe")
          },
          //自定义页
          "/add-apply-info": {
            name: "add-apply-info",
            component: getComponent("module/add-apply-info")
          }
        }
      },
      "/active-info": {
        name: "active-info",
        component: getComponent("module/active-info", 1, true),
        subRoutes: {
          //发布评论
          "/bbs-create": {
            name: "bbs-create",
            component: getComponent("module/bbs-create")
          },
          //活动二维码
          "/qr-code": {
            name: "qr-code",
            component: getComponent("module/qr-code")
          },
          //活动签到二维码
          "/activity-code": {
            name: "activity-code",
            component: getComponent("module/activity-code")
          },
          //查看报名列表
          "/register-list-page": {
            name: "register-list-page",
            component: getComponent("module/register-list-page")
          },
          //查看签到列表
          "/sign-list": {
            name: "sign-list",
            component: getComponent("module/sign-list")
          },
          //发布公告
          "/add-notice": {
            name: "add-notice",
            component: getComponent("module/add-notice")
          },
          //公告列表
          "/notice-list": {
            name: "notice-list",
            component: getComponent("module/notice-list"),
            subRoutes: {
              //发布公告
              "/add-notice": {
                name: "addNotice",
                component: getComponent("module/add-notice")
              }
            }
          },
          //查看活动描述
          "/active-intro": {
            name: "active-intro",
            component: getComponent("module/active-intro")
          },
          //审核列表
          "/approval-list": {
            name: "approval-list",
            component: getComponent("module/approval-list")
          }

        }
      },
      //编辑页
      "/edit-active": {
        name: "edit-active",
        component: getComponent("module/edit-active"),
        subRoutes: {
          //活动描述
          "/describe": {
            name: "edit-describe",
            component: getComponent("module/describe")
          },
          //自定义页
          "/add-apply-info": {
            name: "edit-apply-info",
            component: getComponent("module/edit-apply-info")
          }
        }
      },
      //报名页
      "/apply": {
        name: "apply",
        component: getComponent("module/apply")
      },
      //审核列表
      "/approval-list": {
        name: "approval-list",
        component: getComponent("module/approval-list")
      },
      //错误页
      "/error": {
        name: "error",
        component: getComponent("module/error")
      },
      //错误页
      "/del": {
        name: "del",
        component: getComponent("module/del")
      }
    })
  } else if (config.entry == 106) {//签到页面入口
    router.map({
      "/root": {
        name: "root",
        component: {
          template: ""
        }
      },
      //未报名页面
      "/no-signUp": {
        name: "no-signUp",
        component: getComponent("module/no-signUp")
      },
      //已报名已签到通过状态判断 已报名未签到
      "/signUp-CheckIn": {
        name: "signUp-CheckIn",
        component: getComponent("module/signUp-CheckIn"),
        subRoutes: detailRouter
      }
    });
  } else if (config.entry == 108) {
    router.map({
      "/root": {
        name: "root",
        component: {
          template: ""
        }
      },
      //首页
      "/active-info": detailRouter,
      //错误页
      "/error": {
        name: "error",
        component: getComponent("module/error")
      },
      //错误页
      "/del": {
        name: "del",
        component: getComponent("module/del")
      },
      //分享页
      "/share-active-info": {
        name: "share-active-info",
        component: getComponent("module/share-active-info")
      }
    });
  } else {
    router.map({
      "/root": {
        name: "root",
        component: {
          template: ""
        }
      },
      //首页
      "/index-list": {
        name: "index-list",
        component: getComponent("module/index-list"),
        subRoutes: detailRouter
      },
      "/active-info": {
        name: "active-info",
        component: getComponent("module/active-info", 1, true),
        subRoutes: {
          //发布评论
          "/bbs-create": {
            name: "bbs-create",
            component: getComponent("module/bbs-create")
          },
          //活动二维码
          "/qr-code": {
            name: "qr-code",
            component: getComponent("module/qr-code")
          },
          //活动签到二维码
          "/activity-code": {
            name: "activity-code",
            component: getComponent("module/activity-code")
          },
          //查看报名列表
          "/register-list-page": {
            name: "register-list-page",
            component: getComponent("module/register-list-page")
          },
          //查看签到列表
          "/sign-list": {
            name: "sign-list",
            component: getComponent("module/sign-list")
          },
          //发布公告
          "/add-notice": {
            name: "add-notice",
            component: getComponent("module/add-notice")
          },
          //公告列表
          "/notice-list": {
            name: "notice-list",
            component: getComponent("module/notice-list"),
            subRoutes: {
              //发布公告
              "/add-notice": {
                name: "addNotice",
                component: getComponent("module/add-notice")
              }
            }
          },
          //查看活动描述
          "/active-intro": {
            name: "active-intro",
            component: getComponent("module/active-intro")
          },
          //审核列表
          "/approval-list": {
            name: "approval-list",
            component: getComponent("module/approval-list")
          }

        }
      },
      "/no-active-info": {
        name: "no-active-info",
        component: getComponent("module/no-active-info", 1, true),
        subRoutes: {
          //发布评论
          "/bbs-create": {
            name: "bbs-create",
            component: getComponent("module/bbs-create")
          },
          //活动二维码
          "/qr-code": {
            name: "qr-code",
            component: getComponent("module/qr-code")
          },
          //活动签到二维码
          "/activity-code": {
            name: "activity-code",
            component: getComponent("module/activity-code")
          },
          //查看报名列表
          "/register-list-page": {
            name: "register-list-page",
            component: getComponent("module/register-list-page")
          },
          //查看签到列表
          "/sign-list": {
            name: "sign-list",
            component: getComponent("module/sign-list")
          },
          //发布公告
          "/add-notice": {
            name: "add-notice",
            component: getComponent("module/add-notice")
          },
          //公告列表
          "/notice-list": {
            name: "notice-list",
            component: getComponent("module/notice-list"),
            subRoutes: {
              //发布公告
              "/add-notice": {
                name: "addNotice",
                component: getComponent("module/add-notice")
              }
            }
          },
          //查看活动描述
          "/active-intro": {
            name: "active-intro",
            component: getComponent("module/active-intro")
          }
        }
      },
      //编辑页
      "/edit-active": {
        name: "edit-active",
        component: getComponent("module/edit-active"),
        subRoutes: {
          //活动描述
          "/describe": {
            name: "edit-describe",
            component: getComponent("module/describe")
          },
          //自定义页
          "/add-apply-info": {
            name: "edit-apply-info",
            component: getComponent("module/edit-apply-info")
          }
        }
      },
      "/signUp-CheckIn": {
        name: "signUp-CheckIn",
        component: getComponent("module/signUp-CheckIn"),
        subRoutes: detailRouter
      },
      //报名页
      "/apply": {
        name: "apply",
        component: getComponent("module/apply")
      },
      //审核列表
      "/approval-list": {
        name: "approval-list",
        component: getComponent("module/approval-list")
      },
      //发布页
      "/add-active": {
        name: "add-active",
        component: getComponent("module/add-active"),
        subRoutes: {
          //活动描述
          "/describe": {
            name: "describe",
            component: getComponent("module/describe")
          },
          //自定义页
          "/add-apply-info": {
            name: "add-apply-info",
            component: getComponent("module/add-apply-info")
          }
        }
      },
      //搜索页
      "/search": {
        name: "search",
        component: getComponent("module/search", 0),
        subRoutes: {
          "/activity-code": { //活动签到二维码
            name: "activity-code",
            component: getComponent("module/activity-code")
          },
          //活动详情页
          "/active-info": {
            name: "active-info",
            component: getComponent("module/active-info"),
            subRoutes: {
              "/qr-code": { //二维码
                name: "qr-code",
                component: getComponent("module/qr-code")
              },
              "/activity-code": { //活动签到二维码
                name: "activity-code",
                component: getComponent("module/activity-code")
              },
              "/notice-list": { //公告列表
                name: "notice-list",
                component: getComponent("module/notice-list"),
                subRoutes: {
                  //发布公告
                  "/add-notice": {
                    name: "addNotice",
                    component: getComponent("module/add-notice")
                  }
                }
              },
              "/register-list-page": { //查看报名列表
                name: "register-list-page",
                component: getComponent("module/register-list-page")
              },
              "/sign-list": { //查看签到列表
                name: "sign-list",
                component: getComponent("module/sign-list")
              }
            }
          },
          //编辑页
          "/edit-active": {
            name: "edit-active",
            component: getComponent("module/edit-active"),
            subRoutes: {
              //活动描述
              "/describe": {
                name: "edit-describe",
                component: getComponent("module/describe")
              },
              //自定义页
              "/add-apply-info": {
                name: "edit-apply-info",
                component: getComponent("module/edit-apply-info")
              }
            }
          },
          //报名页
          "/apply": {
            name: "apply",
            component: getComponent("module/apply")
          },
          //审核列表
          "/approval-list": {
            name: "approval-list",
            component: getComponent("module/approval-list")
          }
        }
      },
      //错误页
      "/error": {
        name: "error",
        component: getComponent("module/error")
      },
      //错误页
      "/del": {
        name: "del",
        component: getComponent("module/del")
      },
      //分享页
      "/share-active-info": {
        name: "share-active-info",
        component: getComponent("module/share-active-info")
      },
      "/city-list": {
        name: "city-list",
        component: getComponent("module/city-list")
      }
    });
  }


  router.beforeEach(function (transition) {
    console.log("from:" + transition.from.name + "     to:" + transition.to.name);
    // 标题设置
    config.setTitle(transition);
    // 分享内容设置
    toongine.page.setShareInfo({
      params: {}
    })
    transition.next();
  });

  router.start(app, "#app");
  // 清除入口自带的路由状态，统一由root初始化，保证先登录再进应用
  router.replace({name: "root"});

  // TODO:登录
  function goLogin() {
    console.log('开始登陆' + config.code);
    //有身份场景
    if (config.code && config.entry != 100) {   //发现--热门活动--无身份活动详情

      // 登录
      api.login().then(function (data) {
        if (data.g_feed_id && data.mark === 1) {
          //群组&群主
          config.session = data;
          console.log('群主')
        } else if (data.g_feed_id && data.mark === 2) {
          //群组&群成员
          console.log('群成员')
          config.session = data;
        } else {
          //个人
          console.log('个人')
          config.session = data;
        }

        // 判断首页并跳转 entry为空或者等于2都正常进首页
        if (config.entry == 3) {
          router.replace({name: "active-info", query: {id: config.ac_id}});
        } else if (config.entry == 4) {
          router.replace({name: "approval-list", query: {id: config.ac_id, user_id:config.returnTag.u}});
        } else if (config.entry == 103) {
          //个人名片进入活动
          router.replace({name: "my-list"});
        } else if (config.entry == 105) {
          //发布页入口
          router.replace({name: "add-active"});
        } else if (config.entry == 108) {
          //详情页入口
          router.replace({name: "active-info"});
        } else if (config.entry == 101) {
          //TODO 无身份详情页
          router.replace({name: "no-active-info", query: {id: config.ac_id}});
        } else if (config.entry == 106) {//签到页面
          router.replace({name: "signUp-CheckIn", query: {id: config.ac_id}});
        } else if (config.returnTag) {
          console.log('returnTag' + JSON.stringify(config.returnTag));
          if (config.returnTag.e || config.returnTag.entry) {
            config.returnTag.e = config.returnTag.e || config.returnTag.entry;
            switch (config.returnTag.e) {
              case 3:
                router.replace({name: "no-active-info"});
                break;
              case 4:
                router.replace({name: "approval-list"});
                break;
              case 5:
                router.replace({name: "signUp-CheckIn", query: {ac_id: config.returnTag.a}});
                break;
              default:
                router.replace({name: "index-list"});
            }
          } else {
            router.replace({name: "no-active-info"});
          }
        } else {
          router.replace({name: "index-list"});
        }
      }).catch(function (err) {
        router.replace({name: "error"});
        alert("认证失败", 3000);
      });
    } else if (config.entry == 101) {
      //TODO 无身份详情页
      router.replace({name: "no-active-info", query: {id: config.ac_id}});
    } else if (config.entry == 106) {
      // signUp-CheckIn
      router.replace({name: "signUp-CheckIn", query: {id: config.ac_id}});
    }
  };

  function envConfig(env) {
    switch (env) {
      case '':
      case 'dev':
      case 'test':
        config.my_url = 'http://p100activities.toon.mobi';
        config.p_url = 'http://p100activities.toon.mobi/';
        config.url = 'http://p100activities.toon.mobi';
        config.vote_url = "http://p100activities-vote.toon.mobi/";
        config.toon_url = 'http://p100activities-api.toon.mobi';
        config.share_url = 'http://p100share.toon.mobi';
        config.activity_url = 'http://p100activities.toon.mobi/manifest.json';
        break;
      default:
        config.my_url = 'https://activities.toon.mobi';
        config.p_url = 'https://activities.toon.mobi/';
        config.url = 'https://activities.toon.mobi';
        config.vote_url = "https://activities-vote.toon.mobi/";
        config.toon_url = 'https://activities-api.toon.mobi';
        config.share_url = 'https://share.toon.mobi';
        config.activity_url = 'https://activities.toon.mobi/manifest.json';
    }
    if (/(Toon|toon){1}/.test(window.navigator.userAgent)) {
      toongine.open.getCode({
        callback: function (res) {
          if (res.code == 0) {
            config.code = res.data;
            goLogin();
          } else {
            router.replace({name: "error"});
          }
        }
      });
    } else {
      config.code = config.getQueryStringByName('code');
      goLogin();
    }
  }

  if (/(Toon|toon)/.test(window.navigator.userAgent)) {
    toongine.open.getEnv({
      callback: function (res) {
        console.log(res.data)
        if (res.code == 0) {
          envConfig(res.data);
        } else {
          alert(res.msg)
        }
      }
    })
  } else {
    envConfig('');
  }


  //时间格式化过滤器
  Vue.filter("formatTime", function (time, format) {
    time = time - 0;
    if (!time || isNaN(time)) return "";
    //过去
    var stamp = new Date(time * 1000),
      year = stamp.getFullYear(),
      month = (stamp.getMonth() + 1) > 9 ? (stamp.getMonth() + 1) : "0" + (stamp.getMonth() + 1),
      day = stamp.getDate() > 9 ? stamp.getDate() : "0" + stamp.getDate(),
      hour = stamp.getHours() > 9 ? stamp.getHours() : "0" + stamp.getHours(),
      minute = stamp.getMinutes() > 9 ? stamp.getMinutes() : "0" + stamp.getMinutes(),
      sec = stamp.getSeconds() > 9 ? stamp.getSeconds() : "0" + stamp.getSeconds();
    if (format) {
      format = format.replace("yyyy", year);
      format = format.replace("MM", month);
      format = format.replace("dd", day);
      format = format.replace("hh", hour);
      format = format.replace("mm", minute);
      format = format.replace("ss", sec);
      var dayArr;
      if (format.indexOf("DD") >= 0) {
        dayArr = ["星期天", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六"];
        format = format.replace("DD", dayArr[stamp.getDay()]);
      } else if (format.indexOf("D") >= 0) {
        dayArr = ["周日", "周一", "周二", "周三", "周四", "周五", "周六"];
        format = format.replace("D", dayArr[stamp.getDay()]);
      }
    } else {
      format = year + "-" + month + "-" + day + " " + hour + ":" + minute;
    }
    return format;
  });

  //思源云头像过滤器
  Vue.filter("getThumbnail", function (url) {
    if (!url) {
      return "http://static1.systoon.com/share/img/185x185.png";
    }
    //静态服务器头像
    if (url.indexOf("http://img.icon.systoon.com") >= 0) {
      return url;
    }
    var w = 80, h = 80, q = 100;
    var path = url.substr(0, url.lastIndexOf("."));
    var mimeType = url.substring(url.lastIndexOf("."), url.length);
    return path + "_" + w + "_" + h + "_" + q + "_1" + mimeType;
  });

  Vue.filter("getDateToText", function (param) {
    if (isNaN(param * 1) && param.indexOf("-") < 0) {
      switch (param) {
        case "today":
          return "今天";
          break;
        case "tomorrow":
          return "明天";
          break;
        case "houtian":
          return "后天";
          break;
        case "week1":
          return "星期一";
          break;
        case "week2":
          return "星期二";
          break;
        case "week3":
          return "星期三";
          break;
        case "week4":
          return "星期四";
          break;
        case "week5":
          return "星期五";
          break;
        case "week6":
          return "星期六";
          break;
        case "week7":
          return "星期日";
          break;
        case "nextweek":
          return "下周";
          break;
      }
    } else if (!isNaN(param * 1)) {
      return param + "月";
    } else if (param.indexOf("-") >= 0) {
      return param.replace("-", "年") + "月";
    }
  });
  return router;
});
