/**
 * 对话框
 *              -- Created by haochai on 16/8/22.
 *              --Modified by DioZhu on 2016.9.22
 *
 * 添加了单行文字提示, 半透明背景, 只传入字符串即可, 2秒后自动隐藏.
 *              --Modified by DioZhu on 2016.11.7
 *
 */
define(["vue", "common/config", "common/api", "core", "text!tplPath/v-dialog.html"], function (Vue, config, api, core, tpl) {
  var defaults = {
    visible: false, // 是否显示对话框
    messageVisible: false,  // 单行提示, 不带按钮且自动渐隐的样式
    content: '',
    //buttons: ['确定'],
    buttons: [{name: '确定', func: null, cls: 'blue'}],
    loop: false,
    loopTime: 1000,
    //leftFunc: null,
    //rightFunc: null,
    doneFunc: null,
    containStyle: {
      "marginTop": "0px"
    }
  };
  var module = Vue.extend({
    template: tpl,
    data: function () {
      console.log("pipeline dialog vue.data");
      return {
        visible: defaults.visible, // 是否显示对话框
        messageVisible: defaults.messageVisible,  // 单行提示, 不带按钮且自动渐隐的样式
        content: defaults.content,
        buttons: defaults.buttons,
        loop: defaults.loop,
        loopTime: defaults.loopTime,
        doneFunc: defaults.doneFunc,
        containStyle: {
          marginTop: defaults.containStyle.marginTop
        }
      };
      //return defaults;
    },
    methods: {
      hide: function () {
        console.log("dialog methods.hide");
        if (this.doneFunc) {
          var func = this.doneFunc;
          this.$nextTick(func);
        }
        for (var key in defaults) {
          if (defaults.hasOwnProperty(key)) {
            this.$set(key, defaults[key]);
          }
        }
        document.body.style.overflow = "visible"; // 取消滚动限制
      },
      show: function () {
        console.log("dialog methods.show");
        this.$set('visible', true);
        if (this.loop) {
          setTimeout(this.hide, this.loopTime);
        }
        this.$nextTick(function () {
          var el = document.querySelector('.contain');
          this.$set('containStyle.marginTop', -el.clientHeight / 2 + 'px');
        });
        document.body.style.overflow = "hidden"; // 取消滚动限制
      },
      clickFunc: function (idx) {
        console.log("dialog methods.click: ", idx);
        if (this.buttons[idx].func) {
          var func = this.buttons[idx].func;
          this.$nextTick(func);
        }
        this.hide();
      }
    },
    events: {
      "dialog.show": function (args) {
        var _self = this;
        console.log("dialog events.dialog.show: ", args);
        _self.content = args.content;
        _self.buttons = args.buttons;
        _self.visible = true;
        _self.messageVisible = false;
        if (arguments.length === 1 && typeof arguments[0] === "string") { // 文字用message模式
          _self.content = arguments[0];
          _self.visible = false;
          _self.messageVisible = true;
          return;
        }
        if (this.visible) {
          console.warn('dialog has been opened!');
          return;
        }
//                var opts = utils.extendOptions(defaults, args);
//                for (var key in this.$data) {
//                    if (this.$data.hasOwnProperty(key)) {
//                        this.$set(key, opts[key]);
//                    }
//                }
        this.show();
      }
    }
  });
  Vue.component('v-dialog', module);
});